@@ -28,10 +28,12 @@ ro_client_kwargs = None
 try:
     ro_client_kwargs = myconfigs['oto.ini']['s3_all_ro']
 except Exception:
+    pass
+
+if ro_client_kwargs is None:
     warn("You don't have the myconfigs['oto.ini']['s3_all_ro'], which I need to be able to access s3. "
          "This means you won't be able to access the audio data.")
 
-assert ro_client_kwargs is not None
 
 def delete_empty_records(s):
     """To delete all empty (i.e. length 0) items of a store"""
@@ -80,6 +82,7 @@ s3_path_p = re.compile('^(?P<protocol>[^:]+)://(?P<bucket>[^/]+)/(?P<path>.*)')
 s3_chks_tmpl = 's3://{group}/learn_mode/sounds/{user}/{channel}/{day}/{bt}_{tt}'
 local_chks_tmpl = '{group}/{user}/{channel}/{day}/{bt}_{tt}'
 
+
 def parse_sref(k):
     m = s3_path_p.match(k)
     if m:
@@ -133,11 +136,15 @@ class Dacc:
         for sref in srefs_selected:
             yield sref, get_wfsr(sref)
 
-    def tag_wf_gen(self, tags, assert_sr):
+    def wf_tag_gen(self, tags, assert_sr):
+        """Get a (wf, tag) pairs iterator for given tags"""
         for sref, tag, (wf, sr) in self.sref_tag_wfsr_gen(tags):
             if assert_sr is not None:
                 assert sr == assert_sr, f"You are asserting sr={assert_sr}, but I got {sr}"
-            yield tag, wf
+            yield wf, tag
+
+    def tag_wf_gen(self, tags, assert_sr):
+        yield from ((tag, wf) for wf, tag in self.wf_tag_gen(tags, assert_sr))
 
     def sref_tag_bytes_gen(self, tags):
         for tag in tags:
@@ -170,6 +177,10 @@ class Dacc:
 
         return df
 
+    @lazyprop
+    def _fv_mgc_zip_filepath(self):
+        return self.djoin(self._fv_mgc_subdir + '.zip')
+
     @lazyprop
     def _path_sref_tag_df_pkl(self):
         return self.djoin(self._sref_tag_df_pkl)
@@ -186,3 +197,43 @@ class Dacc:
     @lazyprop
     def tag_counts(self):
         return pd.Series(Counter(self.sref_tag_df['tag'])).sort_values(ascending=False)
+
+    @lazyprop
+    def tagged_fvs_of_users(self):
+        """A store whose keys are (group, user) pairs and values are (_id, deviceHwId, tag, fv) DataFrames"""
+        from py2store import FilesOfZip, kv_wrap
+        import json
+
+        class TaggedFvsTrans:
+            def _id_of_key(self, k):
+                return self.rootdir + '/'.join(k)
+
+            def _key_of_id(self, _id):
+                return tuple(_id[len(self.rootdir):].split('/'))
+
+            def _obj_of_data(self, data):
+                return pd.DataFrame(json.loads(data.decode()))
+
+            # The key mapping depends on a rootdir attr that needs to be defined in the class that will be wrapped.
+            # To indicate this to the user (and your IDE linter) you can do this:
+
+            # rootdir = None  # to be defined in subclass
+            # or this:
+            @property
+            def rootdir(self):
+                raise NotImplementedError("This is supposed to be set in the class that will be wrapped")
+
+        from py2store import kv_wrap
+
+        @kv_wrap(TaggedFvsTrans)
+        class TaggedFvs(FilesOfZip):
+            rootdir = self._fv_mgc_subdir + '/'  # you could also write a new __init__ that would take it as a arg (+ the ones of FilesOfZip)
+
+        return TaggedFvs(self._fv_mgc_zip_filepath)
+
+
+_meta = dict(
+    name='iatis',
+    description='Over 5 million tagged sounds',
+    mk_dacc=Dacc
+)
